package ast

// WhileStmt is node represent 'while'
type WhileStmt struct {
	Addr       Address
	Pos        Position
	ChildNodes []Node
}

func parseWhileStmt(line string) Node {
	groups := groupsFromRegex(
		"<(?P<position>.*)>",
		line,
	)
	if groups == nil {
		return &Unknown{}
	}

	return &WhileStmt{
		Addr:       ParseAddress(groups["address"]),
		Pos:        NewPositionFromString(groups["position"]),
		ChildNodes: []Node{},
	}
}

// AddChild adds a new child node. Child nodes can then be accessed with the
// Children attribute.
func (n *WhileStmt) AddChild(node Node) {
	n.ChildNodes = append(n.ChildNodes, node)
}

// Address returns the numeric address of the node. See the documentation for
// the Address type for more information.
func (n *WhileStmt) Address() Address {
	return n.Addr
}

// Children returns the child nodes. If this node does not have any children or
// this node does not support children it will always return an empty slice.
func (n *WhileStmt) Children() []Node {
	return n.ChildNodes
}

// Position returns the position in the original source code.
func (n *WhileStmt) Position() Position {
	return n.Pos
}
